InternedPathMap

Type Alias InternedPathMap 

pub type InternedPathMap<V> = HashMap<InternedPath, V, BuildHasherDefault<IdentityHasher>>;
A standard HashMap using InternedPath as the key type with a custom Hasher that just uses the precomputed hash for speed instead of calculating it.

Aliased Type

pub struct InternedPathMap<V> { /* private fields */ }