pub type InternedPathSet = HashSet<InternedPath, BuildHasherDefault<IdentityHasher>>;Expand description
A standard HashSet using InternedPath as the key type with a custom Hasher
that just uses the precomputed hash for speed instead of calculating it.
Aliased Type
pub struct InternedPathSet { /* private fields */ }